==> libplasma-6.1.90.tar.xz: libplasma-6.1.90/src/desktoptheme/breeze/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[ar]": "مجموعة التصميم المرئي لكِيدِي",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[be]": "Суполка візуальнага дызайну KDE",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[cs]": "Skupina vizuálního návrhu KDE",
                "Name[da]": "KDE visuelle designgruppe",
                "Name[de]": "KDE Visual Design Group",
                "Name[el]": "Ομάδα οπτικού σχεδιασμού KDE",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[eo]": "KDE Vida Dezajna Grupo",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[gl]": "Grupo de deseño visual de KDE",
                "Name[he]": "קבוצת העיצוב החזותי של KDE",
                "Name[hu]": "KDE Visual Design Group",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[is]": "Myndrænn hönnunarhópur KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ka]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[lt]": "KDE vaizdinio dizaino grupė",
                "Name[lv]": "KDE Vizuālā dizaina grupa",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[pt_BR]": "Grupo de design visual do KDE (KDE VDG)",
                "Name[ro]": "KDE Visual Design Group",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sa]": "KDE Visual Design Group",
                "Name[sk]": "KDE Visual Design Group",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[ta]": "கே.டீ.யீ. வரைகலை வடிவமைப்புக் குழு",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队",
                "Name[zh_TW]": "KDE VDG 視覺設計組"
            }
        ],
        "Category": "",
        "Description": "Breeze by the KDE VDG",
        "Description[ar]": "نسيم من مجموعة تصميم كِيدِي",
        "Description[az]": "KDE VDG tərəfindən Breeze İş mühiti görünüşü",
        "Description[be]": "Breeze ад KDE VDG",
        "Description[bg]": "Breeze от KDE VDG",
        "Description[ca@valencia]": "Brisa, creat pel VDG de KDE",
        "Description[ca]": "Brisa, creat pel VDG del KDE",
        "Description[cs]": "Breeze od KDE VDG",
        "Description[da]": "Breeze af KDE's visuelle designgruppe",
        "Description[de]": "Breeze von der KDE VDG",
        "Description[el]": "Breeze από το KDE VDG",
        "Description[en_GB]": "Breeze by the KDE VDG",
        "Description[eo]": "Brizo de la KDE VDG",
        "Description[es]": "Brisa, por KDE VDG",
        "Description[eu]": "Brisa KDEren VDGk egina",
        "Description[fi]": "Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze par l'équipe « KDE VDG »",
        "Description[gl]": "Brisa do KDE VDG.",
        "Description[he]": "בריזה מאת קבוצת העיצוב החזותי של KDE",
        "Description[hu]": "Breeze a KDE VDG-től",
        "Description[ia]": "Breeze (Brisa) per le KDE VDG",
        "Description[id]": "Breeze oleh KDE VDG",
        "Description[is]": "Breeze frá KDE VDG",
        "Description[it]": "Brezza a cura del KDE VDG",
        "Description[ka]": "Breeze KDE VDG-სგან",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 Breeze",
        "Description[lt]": "Breeze pagal KDE VDG",
        "Description[lv]": "KDE VDG veidotā „Breeze“",
        "Description[nl]": "Breeze door de KDE VDG",
        "Description[nn]": "Breeze frå KDE VDG",
        "Description[pl]": "Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa da VDG do KDE",
        "Description[pt_BR]": "Breeze pelo KDE VDG",
        "Description[ro]": "Briză, de KDE VDG",
        "Description[ru]": "Оформление рабочей среды Breeze от KDE VDG",
        "Description[sa]": "KDE VDG द्वारा Breeze",
        "Description[sk]": "Vánok od KDE VDG",
        "Description[sl]": "Sapica od KDE VDG",
        "Description[sv]": "Breeze av KDE:s visuella designgrupp",
        "Description[ta]": "கே.டீ.யீ. VDG வழங்கும் பிரீஸ்",
        "Description[tr]": "KDE VDG tarafından Esinti",
        "Description[uk]": "Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze, do KDE VDG",
        "Description[x-test]": "xxBreeze by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风主题，由 KDE VDG (视觉设计团队) 设计制作",
        "Description[zh_TW]": "由 KDE VDG 設計的 Breeze",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze",
        "Name[ar]": "نسيم",
        "Name[az]": "Breeze",
        "Name[be]": "Breeze",
        "Name[bg]": "Breeze",
        "Name[ca@valencia]": "Brisa",
        "Name[ca]": "Brisa",
        "Name[cs]": "Breeze",
        "Name[da]": "Breeze",
        "Name[de]": "Breeze",
        "Name[el]": "Breeze",
        "Name[en_GB]": "Breeze",
        "Name[eo]": "Vento",
        "Name[es]": "Brisa",
        "Name[eu]": "Brisa",
        "Name[fi]": "Breeze",
        "Name[fr]": "Breeze",
        "Name[gl]": "Brisa",
        "Name[he]": "בריזה",
        "Name[hu]": "Breeze",
        "Name[ia]": "Brisa",
        "Name[id]": "Breeze",
        "Name[is]": "Breeze",
        "Name[it]": "Brezza",
        "Name[ka]": "ნიავი",
        "Name[ko]": "Breeze",
        "Name[lt]": "Breeze",
        "Name[lv]": "Breeze",
        "Name[nl]": "Breeze",
        "Name[nn]": "Breeze",
        "Name[pl]": "Bryza",
        "Name[pt]": "Brisa",
        "Name[pt_BR]": "Breeze",
        "Name[ro]": "Briză",
        "Name[ru]": "Breeze",
        "Name[sa]": "Breeze",
        "Name[sk]": "Vánok",
        "Name[sl]": "Sapica",
        "Name[sv]": "Breeze",
        "Name[ta]": "பிரீஸ்",
        "Name[tr]": "Esinti",
        "Name[uk]": "Breeze",
        "Name[vi]": "Breeze",
        "Name[x-test]": "xxBreezexx",
        "Name[zh_CN]": "Breeze 微风",
        "Name[zh_TW]": "Breeze",
        "Version": "@KF6_MIN_VERSION@",
        "Website": "https://www.kde.org/"
    },
    "X-Plasma-API": "5.0"
}

==> libplasma-6.3.2.tar.xz: libplasma-6.3.2/src/desktoptheme/breeze/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[ar]": "مجموعة التصميم المرئي لكِيدِي",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[be]": "Суполка візуальнага дызайну KDE",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[cs]": "Skupina vizuálního návrhu KDE",
                "Name[da]": "KDE visuelle designgruppe",
                "Name[de]": "KDE Visual Design Group",
                "Name[el]": "Ομάδα οπτικού σχεδιασμού KDE",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[eo]": "KDE Vida Dezajna Grupo",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[gl]": "Grupo de deseño visual de KDE",
                "Name[he]": "קבוצת העיצוב החזותי של KDE",
                "Name[hi]": "केडीई विज़ुअल डिज़ाइन समूह",
                "Name[hu]": "KDE Visual Design Group",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[is]": "Myndrænn hönnunarhópur KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ka]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[lt]": "KDE vaizdinio dizaino grupė",
                "Name[lv]": "KDE Vizuālā dizaina grupa",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[pt_BR]": "Grupo de design visual do KDE (KDE VDG)",
                "Name[ro]": "KDE Visual Design Group",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sa]": "KDE Visual Design Group",
                "Name[sk]": "KDE Visual Design Group",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[ta]": "கே.டீ.யீ. வரைகலை வடிவமைப்புக் குழு",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队",
                "Name[zh_TW]": "KDE VDG 視覺設計組"
            }
        ],
        "Category": "",
        "Description": "Breeze by the KDE VDG",
        "Description[ar]": "نسيم من مجموعة تصميم كِيدِي",
        "Description[az]": "KDE VDG tərəfindən Breeze İş mühiti görünüşü",
        "Description[be]": "Breeze ад KDE VDG",
        "Description[bg]": "Breeze от KDE VDG",
        "Description[ca@valencia]": "Brisa, creat pel VDG de KDE",
        "Description[ca]": "Brisa, creat pel VDG del KDE",
        "Description[cs]": "Breeze od KDE VDG",
        "Description[da]": "Breeze af KDE's visuelle designgruppe",
        "Description[de]": "Breeze von der KDE VDG",
        "Description[el]": "Breeze από το KDE VDG",
        "Description[en_GB]": "Breeze by the KDE VDG",
        "Description[eo]": "Brizo de la KDE VDG",
        "Description[es]": "Brisa, por KDE VDG",
        "Description[eu]": "Brisa KDEren VDGk egina",
        "Description[fi]": "Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze par l'équipe « KDE VDG »",
        "Description[gl]": "Brisa do KDE VDG.",
        "Description[he]": "בריזה מאת קבוצת העיצוב החזותי של KDE",
        "Description[hi]": "केडीई वीडीजी द्वारा हवा",
        "Description[hu]": "Breeze a KDE VDG-től",
        "Description[ia]": "Breeze (Brisa) per le KDE VDG",
        "Description[id]": "Breeze oleh KDE VDG",
        "Description[is]": "Breeze frá KDE VDG",
        "Description[it]": "Brezza a cura del KDE VDG",
        "Description[ka]": "Breeze KDE VDG-სგან",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 Breeze",
        "Description[lt]": "Breeze pagal KDE VDG",
        "Description[lv]": "KDE VDG veidotā „Breeze“",
        "Description[nl]": "Breeze door de KDE VDG",
        "Description[nn]": "Breeze frå KDE VDG",
        "Description[pl]": "Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa da VDG do KDE",
        "Description[pt_BR]": "Breeze pelo KDE VDG",
        "Description[ro]": "Briză, de KDE VDG",
        "Description[ru]": "Оформление рабочей среды Breeze от KDE VDG",
        "Description[sa]": "KDE VDG द्वारा Breeze",
        "Description[sk]": "Vánok od KDE VDG",
        "Description[sl]": "Sapica od KDE VDG",
        "Description[sv]": "Breeze av KDE:s visuella designgrupp",
        "Description[ta]": "கே.டீ.யீ. VDG வழங்கும் பிரீஸ்",
        "Description[tr]": "KDE VDG’den Esinti",
        "Description[uk]": "Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze, do KDE VDG",
        "Description[x-test]": "xxBreeze by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风主题，由 KDE VDG (视觉设计团队) 设计制作",
        "Description[zh_TW]": "由 KDE VDG 設計的 Breeze",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze",
        "Name[ar]": "نسيم",
        "Name[az]": "Breeze",
        "Name[be]": "Breeze",
        "Name[bg]": "Breeze",
        "Name[ca@valencia]": "Brisa",
        "Name[ca]": "Brisa",
        "Name[cs]": "Breeze",
        "Name[da]": "Breeze",
        "Name[de]": "Breeze",
        "Name[el]": "Breeze",
        "Name[en_GB]": "Breeze",
        "Name[eo]": "Vento",
        "Name[es]": "Brisa",
        "Name[eu]": "Brisa",
        "Name[fi]": "Breeze",
        "Name[fr]": "Breeze",
        "Name[gl]": "Brisa",
        "Name[he]": "בריזה",
        "Name[hi]": "हवा",
        "Name[hu]": "Breeze",
        "Name[ia]": "Brisa",
        "Name[id]": "Breeze",
        "Name[is]": "Breeze",
        "Name[it]": "Brezza",
        "Name[ka]": "ნიავი",
        "Name[ko]": "Breeze",
        "Name[lt]": "Breeze",
        "Name[lv]": "Breeze",
        "Name[nl]": "Breeze",
        "Name[nn]": "Breeze",
        "Name[pl]": "Bryza",
        "Name[pt]": "Brisa",
        "Name[pt_BR]": "Breeze",
        "Name[ro]": "Briză",
        "Name[ru]": "Breeze",
        "Name[sa]": "Breeze",
        "Name[sk]": "Vánok",
        "Name[sl]": "Sapica",
        "Name[sv]": "Breeze",
        "Name[ta]": "பிரீஸ்",
        "Name[tr]": "Esinti",
        "Name[uk]": "Breeze",
        "Name[vi]": "Breeze",
        "Name[x-test]": "xxBreezexx",
        "Name[zh_CN]": "Breeze 微风",
        "Name[zh_TW]": "Breeze",
        "Version": "@KF6_MIN_VERSION@",
        "Website": "https://www.kde.org/"
    },
    "X-Plasma-API": "5.0"
}
